@@ -21,3 +21,9 @@ from zun_ui.api import rest_api  # noqa: F401
 class Containers(horizon.Panel):
     name = _("Containers")
     slug = "container.containers"
+
+
+class ContainersForAdmin(horizon.Panel):
+    name = _("Containers")
+    slug = "container.containers"
+    urls = "admin_urls"
